Index: trunk/DataCheck/Processing/RunCallisto.sh
===================================================================
--- trunk/DataCheck/Processing/RunCallisto.sh	(revision 14155)
+++ trunk/DataCheck/Processing/RunCallisto.sh	(revision 14193)
@@ -36,13 +36,13 @@
 
 # run callisto 
-printprocesslog "INFO starting callisto5.C for sequence "$seqnum
+printprocesslog "INFO starting callisto6.C for sequence "$seqnum
 setstatus "start" 
 
-check1=`root -q -b fact/callisto5.C\("\"$seqfile\""\,"\"$outpath\""\) | tee $logfile | intgrep`
+check1=`root -q -b fact/callisto6.C\("\"$seqfile\""\,"\"$outpath\""\) | tee $logfile | intgrep`
 
 case $check1 in
    0)   printprocesslog "INFO callisto was successful for sequence "$seqnum" (check1=$check1)"
         ;;
    *)   printprocesslog "ERROR callisto5.C failed for sequence "$seqnum" (check1=$check1)"
         check=$check1
         ;;
@@ -36,13 +36,13 @@
    0)   printprocesslog "INFO callisto was successful for sequence "$seqnum" (check1=$check1)"
         ;;
-   *)   printprocesslog "ERROR callisto5.C failed for sequence "$seqnum" (check1=$check1)"
+   *)   printprocesslog "ERROR callisto6.C failed for sequence "$seqnum" (check1=$check1)"
         check=$check1
         ;;
